## OctoML Profile

OctoML Profile is a Python library and a cloud service
designed to provide the **simplest experience** for running
PyTorch models on cloud hardware with state-of-the-art ML acceleration technology.

It is suited for benchmarking PyTorch-based AI applications before
they are deployed into the cloud.
